Attribute VB_Name = "modResorce"
Option Explicit
'****************************************************************************
'*
'*          CT/FT Series communication demo software
'*              Copyright(c) Neuron Corporation
'*              Version 0.6 Beta     Date:   03/28/2000
'*
'*          Development Language    : Visual Basic 5.0 (Japanese)
'*          ActiveX Control         : Microsoft Comm Control 5.0 (MSComm.ocx)
'*
'*          Project file name       : DemoCTFT.vbp  [proDemoCTFT]
'*          Form module file name   : Main.frm      [frmMain]
'*          Common module file name : Function.bas  [modFunction]
'*                                  : Resource.bas  [modResource]
'*
'*          Supported model : CT-2xxN/CT-6xxN/CT-7xx/CT-8xx Series
'*                            FT-2xx/FT-4xx/FT-5xx/FT-7xx/FT-8xx Series
'*
'****************************************************************************
'*
'*          This file : Resource.bas   [modResource]
'*                      Command codes and application messages module
'*
'****************************************************************************

'---------------------------------------------------------------------------
'           Communication parameter user type declaration
'---------------------------------------------------------------------------
Type CommParameterType
    Port As Integer                 'Port number
    Baudrate As Integer             'Baud rate          [bit/sec]
    BitLength As Byte               'Bit length
    Parity As Byte                  'Parity             [0:NONE, 1:ODD, 2:EVEN]
    StopBit As Byte                 'Stop bit           [1:1bit, 2:2bit, 3:1.5bit]
    RTSEnable As Byte               'RTS line setting   [0:OFF, 1:ON]
    DTREnable As Byte               'DTR line setting   [0:OFF, 1:ON]
    CTSControl As Byte              'CTS line control   [0:no control, 1:control]
    DSRControl As Byte              'DSR line control   [0:no control, 1:control]
    STXEnable As Byte               'STX eneble         [0:no STX, 1:STX]
    ETXEnable As Byte               'ETX enable         [0:no ETX, 1:ETX, 2:CR+LF]
    STX As String                   'STX code
    US As String                    'US code
    ETX As String                   'ETX code
    BCCByte As Byte                 'BCC length
    BCCRange As Byte                'BCC calculate start position [1:STX, 2:STX Next]
    Password As String * 6          'EEPROM open password [6 digit]
    TimeOut As Integer              'Receive waiting time [msec]
End Type

'---------------------------------------------------------------------------
'       Public variable declaration
'---------------------------------------------------------------------------
Public CommParam As CommParameterType       'User type definition
Public Res As Integer                       'Result error message value
Public ACK As String * 1                    'ACK code
Public NAK As String * 1                    'NAK code
Public CAN As String * 1                    'CAN code
Public DLE As String * 1                    'DLE code
Public ENQ As String * 1                    'ENQ code
Public EOT As String * 1                    'EOT code


'---------------------------------------------------------------------------
'       CT/FT command code and response code declaration
'           Model   :FT-2xx,FT-4xx,FT-5xx,CT-2xxN,CT-6xxN series protocol (mode 2)
'                   :FT-7xx,8xx, CT-7xx-5050,8xx-5050 series protocol
'
'           Command data block  [ STX+CMD+(DATA)+ETX+BCC ]      CMD: commnad
'           Response data block [ STX+CMD+{RC+DATA}+ETX+BCC ]   RC : return code
'           Send times CTS control. Receive times no control
'           StopBitFPbit default ***********Chacter after t, F is symbol(box)
'---------------------------------------------------------------------------
Public Const CMD_Prohibit = "0"               '30h      Prohibit command
Public Const CMD_Read = "1"                   '31h      Read command
Public Const CMD_ReadHold = "2"               '32h      Read and card hold command
Public Const CMD_Write = "3"                  '33h      Write command
Public Const CMD_WriteHold = "4"              '34h      Write and card hold command
Public Const CMD_CommCheck = ":"              '3Ah      Communication check command
Public Const CMD_Eject = ";"                  '3Bh      Eject card command
Public Const CMD_Reset = "<"                  '3Ch      Reset unit command
Public Const CMD_Status = "="                 '3Dh      Status command
Public Const CMD_EjectHold = ">"              '3Eh      Eject and card hold command
Public Const CMD_LowCo300 = "62"              '36h + 32h    Low coercivity set command 1
Public Const CMD_LowCo650 = "61"              '36h + 31h    Low coercivity set command 2
Public Const CMD_HiCo = "60"                  '36h + 30h    Hi coercivity set command
'------------- EEPROM Access Command ( FT-7xx,8xx Only) -------------------
Public Const CMD_EROM_Password = "NEURON"     '         Default password "NEURON"
Public Const CMD_EROM_Open = "p"              '70h      EEPROM open command
Public Const CMD_EROM_Close = "v"             '76h      EEPROM close command
Public Const CMD_EROM_Read = "s"              '73h      EEPROM read command
Public Const CMD_EROM_WriteEnable = "q"       '71h      EEPROM write enable command
Public Const CMD_EROM_Write = "t"             '74h      EEPROM write command
Public Const CMD_EROM_WriteDisable = "r"      '72h      EEPROM write disable command
'------------- Response ---------------------------------------------------
Public Const RES_Read = "A"                   '41h      Read response
Public Const RES_ReadHold = "B"               '42h      Read card hold response
Public Const RES_Write = "C"                  '43h      Write response
Public Const RES_WriteHold = "D"              '44h      Write card hold response
Public Const RES_WriteVerify = "W"            '57h      Write verify response (Only manual type)
Public Const RES_CommCheck = "J"              '4Ah      Communication check response
Public Const RES_Status = "M"                 '4Dh      Status response
Public Const RES_RW_OK = "0"                  '30h      Read or write Ok response code
'------------- EEPROM Access Command ( FT-7xx,8xx Only) -------------------
Public Const RES_EROM = "s"                   '73h      EEPROM read response


'---------------------------------------------------------------------------
'       Application messages const declaration
'---------------------------------------------------------------------------
Public Const MSG_Comm_RecDataError = "Communication Data Error" & vbCrLf & "NAK send over flow"
Public Const MSG_Comm_SendDataError = "Communication Data Error. Data send over flow."
Public Const MSG_Comm_BCCError = "   <BCC Error>"
Public Const MSG_Comm_ConfirmData = " Please confirm data box"
Public Const MSG_Comm_CommSetError = "Comm port setting error : "
Public Const MSG_Comm_CommPortClose = "Comm port status : closed"
Public Const MSG_Comm_CommPortOpen = "Comm port status : opened"
Public Const MSG_Comm_CommPortStatus = "Comm port closed! Please open comm port."

'---------------------------------------------------------------------------
'       Response messages const declaration
'---------------------------------------------------------------------------

Public Const MSG_Response_OK = "Command and response OK"
Public Const MSG_Response_Error = "Communication error."
Public Const MSG_Response_CAN = "[CAN] Received"
Public Const MSG_Response_DLE = "[DLE] Received"
Public Const MSG_Response_NAK = "[NAK] Received"
Public Const MSG_Response_ENQ = "[ENQ] Received"
Public Const MSG_Response_None = "No response"
Public Const MSG_ResponseMode_Read = "Read response"
Public Const MSG_ResponseMode_ReadHold = "Read data and card hold"
Public Const MSG_ResponseMode_Write = "Write verify response"
Public Const MSG_ResponseMode_WriteHold = "Write data and card hold"
Public Const MSG_ResponseMode_WriteVerify = "Write verify start"
Public Const MSG_ResponseMode_EEPRom = "EEPROM Data response"
Public Const MSG_ResponseMode_CommCheck = "Communication check response"



